==> 0.0.19.tar.gz: lib/widgets/src/empty_widget.dart <==
import 'package:empty_widget/empty_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class TEmptyWidget extends StatelessWidget {
  const TEmptyWidget({
    Key? key,
    this.title = "空空如也",
    this.subTitle = "",
  }) : super(key: key);

  final String title;
  final String subTitle;

  @override
  Widget build(BuildContext context) {
    return EmptyWidget(
      image: "assets/common/images/null_value_list.png",
      packageImage: null,
      hideBackgroundAnimation: true,
      title: title,
      titleTextStyle: TextStyle(
        fontSize: 12.sp,
        color: const Color(0xffC8C9CC),
        fontWeight: FontWeight.w500,
      ),
      subTitle: subTitle,
      subtitleTextStyle: TextStyle(
        fontSize: 14.sp,
        color: const Color(0xffC8C9CC),
      ),
    );
  }
}


class TNoDataWidget extends StatelessWidget {
  const TNoDataWidget({
    Key? key,
    this.title = "暂无数据",
  }) : super(key: key);

  final String title;

  @override
  Widget build(BuildContext context) {
    return Container(
        alignment: Alignment.center,
        color: Colors.transparent,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image(image: ImageUtils.getAssetImage("assets/common/images/no_data.png"), width: 160.w, height: 160.h, fit: BoxFit.fill,),
            SizedBox(height: 16.h,),
            Text(title, style: TextStyle(color: const Color(0xff969799), fontSize: 16.sp)),
          ],),
    );
  }

}

==> 0.0.26.tar.gz: lib/widgets/src/empty_widget.dart <==
import 'package:empty_widget/empty_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class TEmptyWidget extends StatelessWidget {
  const TEmptyWidget({
    Key? key,
    this.title = "空空如也",
    this.subTitle = "",
  }) : super(key: key);

  final String title;
  final String subTitle;

  @override
  Widget build(BuildContext context) {
    return EmptyWidget(
      image: "assets/images/null_value_list.png",
      packageImage: null,
      hideBackgroundAnimation: true,
      title: title,
      titleTextStyle: TextStyle(
        fontSize: 12.sp,
        color: const Color(0xffC8C9CC),
        fontWeight: FontWeight.w500,
      ),
      subTitle: subTitle,
      subtitleTextStyle: TextStyle(
        fontSize: 14.sp,
        color: const Color(0xffC8C9CC),
      ),
    );
  }
}


class TNoDataWidget extends StatelessWidget {
  const TNoDataWidget({
    Key? key,
    this.title = "暂无数据",
  }) : super(key: key);

  final String title;

  @override
  Widget build(BuildContext context) {
    return Container(
        alignment: Alignment.center,
        color: Colors.transparent,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image(image: ImageUtils.getAssetImage("assets/images/no_data.png", package: "tengits_common"), width: 160.w, height: 160.h, fit: BoxFit.fill,),
            SizedBox(height: 16.h,),
            Text(title, style: TextStyle(color: const Color(0xff969799), fontSize: 16.sp)),
          ],),
    );
  }

}
